@@ -1,4 +1,4 @@
-`choose.M` <-
+choose.M <-
 function(x, theta, params, ind.dichot, ...){
    posterior(x, theta, params, ind.dichot, ...)/dnorm(theta, ...)
 }
